# Modules communs Python de l'INSPQ

Ce package contient les modules communs de l'INSPQ

## Module userprovisioning.scim
 
Implémentation SCIM pour Python

Ce module permet de manipuler les utilisateurs et le groupes SCIM.

Il permet aussi de consommer des services SCIM.

## Module identity.keycloak 

Client Python pour Keycloak

Ce module permet d'interagir avec un serveur Keycloak pour OpenID Connect.

Actuellement, la seule fonctionnalité implantée est l'obtention d'un access token Open ID Connect.